Set the URL of the RCRS Scenario Hub
set_hub_url.Rdset_hub_url sets the URL of the RCRS Scenario Hub for the current session.
The cached scenario list is cleared when the URL is changed.

set_hub_url.Rdset_hub_url sets the URL of the RCRS Scenario Hub for the current session.
The cached scenario list is cleared when the URL is changed.